import type { LightTheme } from '../../types.js';
import { DiscordMediaLifecycle } from '../_private/DiscordMediaLifecycle.js';
import '../discord-link/DiscordLink.js';
export declare class DiscordAudioAttachment extends DiscordMediaLifecycle implements LightTheme {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult[];
    /**
     * The URL to audio file
     *
     * @example
     * ```ts
     * 'https://interactive-examples.mdn.mozilla.net/media/cc0-audio/t-rex-roar.mp3'
     * ```
     */
    accessor href: string;
    /**
     * The name of the audio file
     *
     * @remarks Spaces will be replaced with underscores and any non-alphanumeric characters will be removed
     */
    accessor name: string | undefined;
    /**
     * The size of the audio file in bytes
     *
     * @remarks The unit is not automatically calculated,
     * you should provide it manually through {@link DiscordAudioAttachment.bytesUnit | `bytesUnit`}
     * @example
     * ```ts
     * 1024
     * ```
     */
    accessor bytes: number;
    /**
     * The unit of the audio file in a human-readable format
     *
     * @example
     * ```ts
     * 'KB'
     * ```
     */
    accessor bytesUnit: string;
    accessor lightTheme: boolean;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-audio-attachment': DiscordAudioAttachment;
    }
}
//# sourceMappingURL=DiscordAudioAttachment.d.ts.map