import { LitElement } from 'lit';
export declare class DiscordButton extends LitElement {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    /**
     * The emoji URL to use in the button.
     */
    accessor emoji: string;
    /**
     * The name of the emoji used in the button.
     */
    accessor emojiName: string;
    /**
     * The URL for the button. Setting this will force the button type to be `secondary`.
     */
    accessor url: string;
    /**
     * Whether to show the button as disabled.
     */
    accessor disabled: boolean;
    /**
     * The type of button this is, this will change the color of the button.
     * Valid values: `primary`, `secondary`, `success`, `destructive`.
     */
    accessor type: 'destructive' | 'primary' | 'secondary' | 'success';
    /**
     * An `id` of a modal that should be opened when this button is clicked. This should match the `modal-id` of a `discord-modal` element.
     *
     * @remarks
     * - `discord-modal`s use the HTML [dialog](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dialog) element. and are opened through `<ref>.showModal()`
     * - If {@link DiscordButton.url} is set this will be ignored.
     * - If {@link DiscordButton.disabled} is set this will be ignored.
     */
    accessor modalId: string;
    private readonly validButtonTypes;
    checkType(): void;
    checkParentElement(): void;
    protected handleButtonClick(): void;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-button': DiscordButton;
    }
}
//# sourceMappingURL=DiscordButton.d.ts.map