import { LitElement } from 'lit';
import type { LightTheme } from '../../types.js';
export declare class DiscordCommand extends LitElement implements LightTheme {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult[];
    /**
     * The id of the profile data to use.
     */
    accessor profile: string;
    /**
     * The message author's username.
     *
     * @defaultValue 'User'
     */
    accessor author: string;
    /**
     * The message author's avatar. Can be an avatar shortcut, relative path, or external link.
     */
    accessor avatar: string;
    /**
     * The message author's primary role color.
     * Can be any [CSS color value](https://www.w3schools.com/cssref/css_colors_legal.asp).
     */
    accessor roleColor: string;
    /**
     * The name of the command invoked.
     */
    accessor command: string;
    /**
     * The type of command
     */
    accessor type: 'message_command' | 'slash_command' | 'user_command';
    /**
     * The id of the profile data to use.
     */
    accessor contextUserProfile: string;
    /**
     * The name of user mentioned in context menu
     */
    accessor contextUserName: string;
    /**
     * The image of user mentioned in context menu
     */
    accessor contextUserAvatar: string;
    /**
     * The role color of user mentioned in context menu
     */
    accessor contextUserRoleColor: string;
    /**
     * If the message command user  are bot
     */
    accessor contextUserBot: boolean;
    /**
     * If the user bot are verified
     */
    accessor contextUserBotVerified: boolean;
    /**
     * Whether the referenced context message is from a response of a slash command.
     */
    accessor contextCommandReply: boolean;
    /**
     * Whether the referenced context message contains attachments.
     */
    accessor contextAttachmentReply: boolean;
    /**
     * The referenced message in message command
     */
    accessor contextMessageReply: string;
    /**
     * If the referenced messaga has deleted
     */
    accessor contextMessageDeleted: boolean;
    /**
     * If the context user is a application official of discord
     */
    accessor contextUserOfficialApplication: boolean;
    /**
     * If the context user is a server
     */
    accessor contextUserServer: boolean;
    /**
     * Whether to use compact mode or not.
     */
    accessor compactMode: boolean;
    accessor lightTheme: boolean;
    private readonly validCommandTypes;
    checkType(): void;
    private resolveAvatar;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-command': DiscordCommand;
    }
}
//# sourceMappingURL=DiscordCommand.d.ts.map