import { LitElement } from 'lit';
import type { Emoji } from '../../types.js';
export declare class DiscordCustomEmoji extends LitElement {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    /**
     * The name of the emoji
     */
    accessor name: string;
    /**
     * The emoji URL to use in the message.
     */
    accessor url: string;
    /**
     * A map of emoji names and their data {@link DiscordCustomEmoji.name | name}.
     *
     * This should be keyed as `{ key: { emojiData } }` wherein `key`
     * should occur in the {@link DiscordCustomEmoji.name | name}.
     *
     * By default this component will use the global emojis from
     * {@link getGlobalEmojiUrl}, however on SSR frameworks like Nuxt 3 global config doesn't
     * work so we provide this as an alternative method.
     */
    accessor customEmojisMap: {
        [key: string]: Emoji;
    };
    /**
     * Determines whether or not the emoji is used in an embed, or a message.
     * If it is used in an embed, the sizing is adjusted accordingly.
     */
    accessor embedEmoji: boolean;
    /**
     * Determines whether or not the emoji is of "jumbo size",
     * This means it is larger and is what Discord uses when the message exclusively has emojis,
     * up to a maximum of 30 emojis.
     */
    accessor jumbo: boolean;
    willUpdate(): void;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-custom-emoji': DiscordCustomEmoji;
    }
}
//# sourceMappingURL=DiscordCustomEmoji.d.ts.map