import { LitElement, type TemplateResult } from 'lit';
import type { Emoji, LightTheme } from '../../types.js';
import '../discord-custom-emoji/DiscordCustomEmoji.js';
export declare class DiscordEmbedField extends LitElement implements LightTheme {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    accessor fieldTitle: string;
    /**
     * An emoji that is prefixed to {@link DiscordEmbedField.fieldTitle | fieldTitle}.
     *
     * This should be keyed as `{ key: { emojiData } }` wherein `key`
     * should occur in the {@link DiscordEmbedField.fieldTitle | fieldTitle}.
     *
     * By default this component will use the global emojis from
     * {@link getGlobalEmojiUrl}, however on SSR frameworks like Nuxt 3 global config doesn't
     * work so we provide this as an alternative method.
     */
    accessor embedFieldEmojisMap: {
        [key: string]: Emoji;
    };
    /**
     * Whether this field should be displayed inline or not.
     */
    accessor inline: boolean;
    /**
     * The index of this inline field
     *
     * @remarks
     * - This defines the position of this inline field. 1 is left, 2 is middle and 3 is right.
     * - one of `[1, 2, 3]`
     * @defaultValue 1
     */
    accessor inlineIndex: number | undefined;
    accessor lightTheme: boolean;
    private readonly validInlineIndices;
    checkInlineIndex(): void;
    protected render(): TemplateResult<1>;
    private parseTitle;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-embed-field': DiscordEmbedField;
    }
}
//# sourceMappingURL=DiscordEmbedField.d.ts.map