import { LitElement, type TemplateResult } from 'lit';
import type { Emoji, LightTheme } from '../../types.js';
import '../discord-custom-emoji/DiscordCustomEmoji.js';
export declare class DiscordEmbed extends LitElement implements LightTheme {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    /**
     * The color to use for the embed's left border.
     * Can be any [CSS color value](https://www.w3schools.com/cssref/css_colors_legal.asp).
     */
    accessor color: string;
    /**
     * The author's name.
     */
    accessor authorName: string;
    /**
     * The author's avatar URL.
     */
    accessor authorImage: string;
    /**
     * The URL to open when you click on the author's name.
     */
    accessor authorUrl: string;
    /**
     * The embed title.
     */
    accessor embedTitle: string;
    /**
     * An emoji that is prefixed to {@link DiscordEmbed.embedTitle | embedTitle}.
     *
     * This should be keyed as `{ key: { emojiData } }` wherein `key`
     * should occur in the {@link DiscordEmbed.embedTitle | embedTitle}.
     *
     * By default this component will use the global emojis from
     * {@link getGlobalEmojiUrl}, however on SSR frameworks like Nuxt 3 global config doesn't
     * work so we provide this as an alternative method.
     */
    accessor embedEmojisMap: {
        [key: string]: Emoji;
    };
    /**
     * The URL to open when you click on the embed title.
     */
    accessor url: string;
    /**
     * The thumbnail image to use.
     */
    accessor thumbnail: string;
    /**
     * The embed image to use (displayed at the bottom).
     */
    accessor image: string;
    /**
     * The embed video to use (displayed at the bottom, same slot as the image).
     *
     * @remarks
     * - YouTube videos will not be playable on your projects, this is due to YouTube using DASH to play their videos rather
     * than providing the raw media stream (in a container such as mp4 or ogg). Links to regular MP4 files (such as on a CDN) however
     * will autoplay!
     * - Video takes priority over image.
     * - Providing both a video and an image will ensure the image is shown to users with browsers
     * that do not support HTML5 video playback.
     * @example https://download.blender.org/peach/bigbuckbunny_movies/big_buck_bunny_1080p_stereo.ogg
     */
    accessor video: string;
    /**
     * The provider to show above the embed, for example for YouTube videos it will show "YouTube" at the top of the embed (above the author)
     *
     * @example YouTube
     */
    accessor provider: string;
    accessor lightTheme: boolean;
    protected render(): TemplateResult<1>;
    private renderMedia;
    private parseTitle;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-embed': DiscordEmbed;
    }
}
//# sourceMappingURL=DiscordEmbed.d.ts.map