import { LitElement } from 'lit';
import '../discord-link/DiscordLink.js';
import type { LightTheme } from '../../types.js';
export declare class DiscordFileAttachment extends LitElement implements LightTheme {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    /**
     * The name of the file
     *
     * @example
     * ```ts
     * 'example.txt'
     * ```
     */
    accessor name: string;
    /**
     * The size of the file in bytes
     *
     * @remarks The unit is not automatically calculated,
     * you should provide it manually through {@link DiscordFileAttachment.bytesUnit | `bytesUnit`}
     * @example
     * ```ts
     * 1024
     * ```
     */
    accessor bytes: number;
    /**
     * The unit of the file in a human-readable format
     *
     * @example
     * ```ts
     * 'KB'
     * ```
     */
    accessor bytesUnit: string;
    /**
     * The URL to the file, this is passed to `<discord-link>`
     *
     * @example
     * ```ts
     * 'https://example.com/example.txt'
     * ```
     */
    accessor href: string;
    /**
     * The `<a>` tag {@link https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a#rel | `rel`},
     * this is passed to `<discord-link>`
     */
    accessor rel: string;
    /**
     * The `<a>` tag {@link https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a#target | `target`},
     * this is passed to `<discord-link>`
     */
    accessor target: '_blank' | '_parent' | '_self' | '_top';
    /**
     * The `<a>` tag {@link https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a#type | `type`},
     * this is passed to `<discord-link>`
     */
    accessor type: string;
    accessor lightTheme: boolean;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-file-attachment': DiscordFileAttachment;
    }
}
//# sourceMappingURL=DiscordFileAttachment.d.ts.map