import { LitElement } from 'lit';
export declare class DiscordImageAttachment extends LitElement {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    /**
     * The URL for the image attachment
     *
     * @remarks Should be a valid image URL, i.e. matching the regex `/\.(bmp|jpe?g|png|gif|webp|tiff)$/i`
     */
    accessor url: string;
    /**
     * The height of the image in pixels
     */
    accessor height: number;
    /**
     * The width of the image in pixels
     */
    accessor width: number;
    /**
     * The alt text to show in case the image was unable to load
     *
     * @defaultValue 'discord attachment'
     */
    accessor alt: string;
    /**
     * Indicates that you intend to use a custom image element,
     * useful if you want to use something like
     * {@link https://nextjs.org/docs/pages/api-reference/components/image | `next/image`}
     *
     * Once this property is set, use the child element (default slot) to insert
     * the code for the desired image component
     *
     * @remarks Setting this will disable the
     * {@link DiscordImageAttachment.url | `url`}, and {@link DiscordImageAttachment.alt | `alt`} properties.
     */
    accessor customImageElement: boolean;
    componentWillRender(): void;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-image-attachment': DiscordImageAttachment;
    }
}
//# sourceMappingURL=DiscordImageAttachment.d.ts.map