import { LitElement } from 'lit';
import type { LightTheme } from '../../types.js';
export declare class DiscordInvite extends LitElement implements LightTheme {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    /**
     * The server icon to display for the invite.
     */
    accessor icon: string | undefined;
    /**
     * The server's name.
     *
     * @defaultValue 'Discord Server'
     */
    accessor name: string;
    /**
     * The URL to open when you click on the join button.
     */
    accessor url: string;
    /**
     * The number of members online on the server.
     *
     * @defaultValue 0
     */
    accessor online: number;
    /**
     * The number of members on the server.
     *
     * @defaultValue 0
     */
    accessor members: number;
    /**
     * Whether the server is verified.
     * Only works if `partnered` is `false` or `undefined`.
     */
    accessor verified: boolean;
    /**
     * Whether the server is partnered.
     * Only works if `verified` is `false` or `undefined`.
     */
    accessor partnered: boolean;
    /**
     * Invitation embed title.
     *
     * @defaultValue "You've been invited to join a server"
     */
    accessor inviteTitle: string;
    /**
     * The join button.
     *
     * @defaultValue 'Join'
     */
    accessor joinBtn: string;
    accessor lightTheme: boolean;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-invite': DiscordInvite;
    }
}
//# sourceMappingURL=DiscordInvite.d.ts.map