import { LitElement } from 'lit';
import type { LightTheme, DiscordTimestamp } from '../../types.js';
import '../discord-author-info/DiscordAuthorInfo.js';
export declare class DiscordMessage extends LitElement implements LightTheme {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    /**
     * The id of the profile data to use.
     */
    accessor profile: string | undefined;
    /**
     * The message author's username.
     *
     * @defaultValue 'User'
     */
    accessor author: string | undefined;
    /**
     * The message author's avatar. Can be an avatar shortcut, relative path, or external link.
     */
    accessor avatar: string | undefined;
    /**
     * Whether the message author is a bot or not.
     * Only works if `server` and `officialApp` is `false` or `undefined`.
     */
    accessor bot: boolean;
    /**
     * Whether the message author is a server crosspost webhook or not.
     * Only works if `bot` and `officialApp` is `false` or `undefined`.
     */
    accessor server: boolean;
    /**
     * Whether the message author is official app.
     * Only works if `bot` and `server` is `falns`
     */
    accessor officialApp: boolean;
    /**
     * Whether the bot is verified or not.
     * Only works if `bot` is `true`
     */
    accessor verified: boolean;
    /**
     * Whether the author is the original poster.
     */
    accessor op: boolean;
    /**
     * Whether the message has been edited or not.
     */
    accessor edited: boolean;
    /**
     * The message author's primary role color. Can be any [CSS color value](https://www.w3schools.com/cssref/css_colors_legal.asp).
     */
    accessor roleColor: string | undefined;
    /**
     * The message author's role icon URL.
     */
    accessor roleIcon: string | undefined;
    /**
     * The name of the role to use as alternative image text.
     */
    accessor roleName: string | undefined;
    /**
     * The clan's tag icon URL.
     */
    accessor clanIcon: string | undefined;
    /**
     * The name of the clan you are part of
     */
    accessor clanTag: string | undefined;
    /**
     * Whether to highlight this message.
     */
    accessor highlight: boolean;
    /**
     * Whether to make this message ephemeral.
     */
    accessor ephemeral: boolean;
    /**
     * The timestamp to use for the message date.
     *
     * if {@link DiscordMessage.messageBodyOnly} is `true`, this will be shown in the gutter before the message on hover.
     */
    accessor timestamp: DiscordTimestamp;
    /**
     * Whether to use 24-hour format for the timestamp.
     */
    accessor twentyFour: boolean;
    accessor messageBodyOnly: boolean;
    accessor lightTheme: boolean;
    accessor compactMode: boolean;
    accessor noBackground: boolean;
    accessor hasThread: boolean;
    accessor dismissMessageClicked: () => void;
    protected willUpdate(): void;
    private handleSpaceToDismissMessage;
    protected render(): import("lit-html").TemplateResult<1>;
    private resolveAvatar;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-message': DiscordMessage;
    }
}
//# sourceMappingURL=DiscordMessage.d.ts.map