import { LitElement } from 'lit';
import type { LightTheme } from '../../types.js';
export declare class DiscordReaction extends LitElement implements LightTheme {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    /**
     * The reaction emoji image URL.
     */
    accessor emoji: string;
    /**
     * The name of the emoji to use as alternative image text.
     *
     * @defaultValue ':emoji'
     */
    accessor name: string;
    /**
     * The number of people who reacted.
     *
     * @defaultValue 1
     */
    accessor count: number;
    /**
     * Whether the reaction should show as reacted by the user.
     *
     * @defaultValue false
     */
    accessor reacted: boolean;
    /**
     * Whether the reaction should be reactive.
     *
     * @remarks When the reaction is interactive left clicking it will add 1 to the counter.
     * Whereas when holding the Shift key and left clicking it will decrease the counter.
     * The counter cannot go below 1.
     * @defaultValue false
     */
    accessor interactive: boolean;
    accessor lightTheme: boolean;
    protected render(): import("lit-html").TemplateResult<1>;
    private readonly handleReactionClick;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-reaction': DiscordReaction;
    }
}
//# sourceMappingURL=DiscordReaction.d.ts.map