import { LitElement } from 'lit';
import type { LightTheme } from '../../types.js';
export declare class DiscordReply extends LitElement implements LightTheme {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    /**
     * The id of the profile data to use.
     */
    accessor profile: string;
    /**
     * The message author's username.
     *
     * @defaultValue 'User'
     */
    accessor author: string;
    /**
     * The message author's avatar. Can be an avatar shortcut, relative path, or external link.
     */
    accessor avatar: string;
    /**
     * Whether the message author is a bot or not.
     * Only works if `server` and `officialApp` is `false` or `undefined`.
     */
    accessor bot: boolean;
    /**
     * Whether the message author is a server crosspost webhook or not.
     * Only works if `bot` and `officialApp` is `false` or `undefined`.
     */
    accessor server: boolean;
    /**
     * Whether the message author is a server crosspost webhook or not.
     * Only works if `bot` and `server` is `false` or `undefined`.
     */
    accessor officialApp: boolean;
    /**
     * Whether the author is the original poster.
     */
    accessor op: boolean;
    /**
     * Whether the bot is verified or not.
     * Only works if `bot` is `true`
     */
    accessor verified: boolean;
    /**
     * Whether the message has been edited or not.
     */
    accessor edited: boolean;
    /**
     * The message author's primary role color. Can be any [CSS color value](https://www.w3schools.com/cssref/css_colors_legal.asp).
     */
    accessor roleColor: string;
    /**
     * Whether the referenced message is from a response of a slash command.
     */
    accessor command: boolean;
    /**
     * Whether the referenced message contains attachments.
     */
    accessor attachment: boolean;
    /**
     * Whether this reply pings the original message sender, prepending an "\@" on the author's username.
     */
    accessor mentions: boolean;
    /**
     * The clan icon of the author, which comes from the enabled clan tag
     */
    accessor clanIcon: string;
    /**
     * The clan name of the author, which comes from the enabled clan tag
     */
    accessor clanTag: string;
    /**
     * Whether this reply is a deleted message.
     * When set to true, any content inside the tags is ignored as no `slot` is rendered.
     * The message will always be `"Original message was deleted"`.
     * Furthermore, the following properties are ignored:
     *
     * - {@link DiscordReply.profile | profile}
     * - {@link DiscordReply.author | author}
     * - {@link DiscordReply.avatar | avatar}
     * - {@link DiscordReply.bot | bot}
     * - {@link DiscordReply.server | server}
     * - {@link DiscordReply.op | op}
     * - {@link DiscordReply.verified | verified}
     * - {@link DiscordReply.edited | edited}
     * - {@link DiscordReply.roleColor | roleColor}
     * - {@link DiscordReply.command | command}
     * - {@link DiscordReply.attachment | attachment}
     * - {@link DiscordReply.mentions | mentions}
     * - {@link DiscordReply.clanIcon | clanIcon}
     * - {@link DiscordReply.clanTag | clanTag}
     */
    accessor deleted: boolean;
    accessor lightTheme: boolean;
    /**
     * Whether to use compact mode or not.
     */
    accessor compactMode: boolean;
    private resolveAvatar;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-reply': DiscordReply;
    }
}
//# sourceMappingURL=DiscordReply.d.ts.map