import { LitElement } from 'lit';
import type { LightTheme } from '../../types.js';
export declare class DiscordThreadMessage extends LitElement implements LightTheme {
    /**
     * @internal
     */
    static readonly styles: import("lit").CSSResult;
    /**
     * The id of the profile data to use.
     */
    accessor profile: string;
    /**
     * The message author's username.
     *
     * @defaultValue 'User'
     */
    accessor author: string;
    /**
     * The message author's avatar. Can be an avatar shortcut, relative path, or external link.
     */
    accessor avatar: string;
    /**
     * Whether the message author is a bot or not.
     * Only works if `server` is `false` or `undefined`.
     */
    accessor bot: boolean;
    /**
     * Whether the message author is a server crosspost webhook or not.
     * Only works if `bot` is `false` or `undefined`.
     */
    accessor server: boolean;
    /**
     * Whether the bot is verified or not.
     * Only works if `bot` is `true`
     */
    accessor verified: boolean;
    /**
     * Whether the message has been edited or not.
     */
    accessor edited: boolean;
    /**
     * The message author's primary role color. Can be any [CSS color value](https://www.w3schools.com/cssref/css_colors_legal.asp).
     */
    accessor roleColor: string;
    /**
     * The relative timestamp of the message.
     */
    accessor relativeTimestamp: string;
    accessor lightTheme: boolean;
    private resolveAvatar;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'discord-thread-message': DiscordThreadMessage;
    }
}
//# sourceMappingURL=DiscordThreadMessage.d.ts.map